Learn R Programming

iGC (version 1.2.2)

hg19DBNM: hg19-RefSeq

Description

The human genome reference used here is RefSeq transcripts in version hg19 from UCSC Genome Browser. The transcripts with NM marker ID, which are protein-codeing, were selected to be our reference database and provided as hg19DBNM.rda.

Usage

hg19DBNM

Arguments

Value

  • data.table

source

UCSC Genome Browser: http://hgdownload.cse.ucsc.edu/downloads.html

Details

This reference provides region information, including chromosome number, starting position, ending position, strand and gene symbols, for converting copy number alteration data into human genes.